import argparse
import logging
from pathlib import Path

from .list import generate_list, write_blacklist, write_results

ROOT_PATH = Path("./lists")
BLACKLIST = Path("./blacklists")
RESULTS = Path("./results")
NUM_MUS = 2


def main():
    # Lecture arguments console
    parser = argparse.ArgumentParser(
        prog="python -m musik",
        description="Lancer une partie de Musik",
        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
    )
    parser.add_argument(
        "-a",
        "--no-api",
        action="store_true",
        help="Désactiver l'API Youtube ; affiche la liste des liens",
    )
    parser.add_argument(
        "-b",
        "--no-blacklist",
        action="store_true",
        help="Désactiver le méchanisme de blacklist en lecture et écriture",
    )
    parser.add_argument(
        "-n",
        "--number",
        type=int,
        default=NUM_MUS,
        help="Modifier le nombre de musiques par joueur",
    )
    parser.add_argument(
        "--lists",
        type=Path,
        default=ROOT_PATH,
        help="Sélectionner le dossier contenant les listes de musiques",
    )
    parser.add_argument(
        "--blacklists",
        type=Path,
        default=BLACKLIST,
        help="Sélectionner le dossier contenant les blacklist",
    )
    parser.add_argument(
        "--results",
        type=Path,
        default=RESULTS,
        help="Sélectionner le dossier pour stocker les résultats",
    )
    parser.add_argument(
        "-v",
        "--verbose",
        action="store_const",
        const=logging.DEBUG,
        default=logging.INFO,
    )

    args = parser.parse_args()
    if not args.no_api:
        from .youtube import create_playlist

    # Configuration logs
    logger = logging.getLogger("musik")
    logging.basicConfig(
        level=args.verbose, format="%(asctime)s\t%(levelname)s\t%(message)s"
    )

    logger.info("Vérification")
    if not args.lists.is_dir():
        logger.error(f"Le dossier <{args.lists}> n'existe pas.")
        return
    if not args.blacklists.is_dir():
        logger.warning(f"Le dossier <{args.blacklists}> n'existe pas, il va être créé.")
        args.blacklists.mkdir()
    if not args.results.is_dir():
        logger.warning(f"Le dossier <{args.results}> n'existe pas, il va être créé.")
        args.results.mkdir()
    if args.number < 1:
        logger.error("Le nombre de musiques est inférieur à 1.")
        return

    # Lecture des fichiers musique dans ROOT_PATH
    # Faire un dossier différent pour les gens qui ne jouent pas
    logger.info("Génération de la liste de musiques")
    musik_list = generate_list(args)

    if not args.no_api:
        create_playlist(musik_list)
    else:
        logger.info("Liste des musiques :")
        for _, musik in musik_list:
            logger.info(f"# https://www.youtube.com/watch?v={musik}")

    # Écriture des résultats
    logger.info("Écriture des résultats")
    write_results(musik_list, args)

    # Écriture de la blacklist
    if not args.no_blacklist:
        logger.info("Écriture de la blacklist")
        write_blacklist(musik_list, args)


if __name__ == "__main__":
    main()
